@@ -36,7 +36,7 @@ except:
 # Global Var
 verify_registered_email = list()
 ALLOWED_EXTENSIONS = {'txt', 'pdf', 'png', 'jpg', 'jpeg', 'gif'}
-Release = 'v0.1.3.5.2 Release'
+Release = 'v0.1.3.6 Release'
 
 
 # Get Configs File
